.. Chronumental documentation master file, created by
   sphinx-quickstart on Wed May 18 17:00:36 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Metafitch's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Installation
============
To install Chronumental using pip, run:

      pip install metafitch
      

Usage
============
.. argparse::
   :module: metafitch.metafitch
   :func: get_parser
   :prog: metafitch



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
